/*
 * Created on 18.09.2006 for PIROL
 *
 * SVN header information:
 *  $Author$
 *  $Rev$
 *  $Date$
 *  $Id$
 */
package de.fhOsnabrueck.jump.pirol.ui.dialogs;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Frame;

import javax.swing.JDialog;
import javax.swing.JPanel;

import de.fhOsnabrueck.jump.pirol.ui.eventHandling.OKCancelListener;
import de.fhOsnabrueck.jump.pirol.ui.panels.OkCancelButtonPanel;
import de.fhOsnabrueck.jump.pirol.ui.tools.ValueChecker;
import de.fhOsnabrueck.jump.pirol.utilities.debugOutput.DebugUserIds;
import de.fhOsnabrueck.jump.pirol.utilities.debugOutput.PersonalLogger;
import de.fhOsnabrueck.jump.pirol.utilities.i18n.PirolPlugInMessages;

/**
 * Standard dialog, that has an OK/Cancel panel and offers a panel
 * to be filled with dialog content.
 *
 * <br><br><b>Last change by $Author$ on $Date$</b>
 *
 * @author Ole Rahn
 * <br>
 * <br>FH Osnabr&uuml;ck - University of Applied Sciences Osnabr&uuml;ck,
 * <br>Project: PIROL (2006),
 * <br>Subproject: Daten- und Wissensmanagement
 * 
 * @version $Rev$
 * 
 */
public abstract class StandardDialog extends JDialog {

	private static final long serialVersionUID = -1396724273468783920L;

	protected OkCancelButtonPanel okCancelButtonPanel = new OkCancelButtonPanel();
	protected OKCancelListener okCancelListener = null;
	
	private JPanel contentPanel = null;
	
	protected Dimension defaulDimension = new Dimension(300,400);
	
	protected PersonalLogger logger = new PersonalLogger(DebugUserIds.OLE);
	
	protected final static int defaultMargin = 5;
	
	public StandardDialog(Frame parent, String titleResourceKey){
		super(parent, PirolPlugInMessages.getString(titleResourceKey), true);
		this.okCancelListener = new OKCancelListener(this);
		this.okCancelButtonPanel.addActionListener(this.okCancelListener);
		this.setupContentPanel();
		this.setSize(this.defaulDimension);
	}

	private void setupContentPanel() {
		this.setLayout(new BorderLayout());
		
		this.contentPanel = this.getContentPanel();
		
		this.getContentPane().add(this.contentPanel, BorderLayout.CENTER);
		this.getContentPane().add(this.okCancelButtonPanel, BorderLayout.SOUTH);
	}
	
	/**
	 * call {@link #getContentPanel()} and fill the panel
	 * with content!
	 */
	public abstract void initializeContent();
	

	public JPanel getContentPanel() {
		if (this.contentPanel==null){
			this.contentPanel = new JPanel();
		}
		return contentPanel;
	}

	public boolean wasOkClicked() {
		return okCancelListener.wasOkClicked();
	}

	public void addValueChecker(ValueChecker valChecker) {
		okCancelListener.addValueChecker(valChecker);
	}
	
}
