/*
 * Created on 05.04.2006 for PIROL
 *
 * SVN header information:
 *  $Author: LBST-PF-3\orahn $
 *  $Rev: 2519 $
 *  $Date: 2006-10-11 11:53:07 +0200 (Mi, 11 Okt 2006) $
 *  $Id: AbstractEllipsoid.java 2519 2006-10-11 09:53:07Z LBST-PF-3\orahn $
 */
package de.fhOsnabrueck.jump.pirol.utilities.projection.ellipsoid;


/**
 * Abstract base class for classes that hold ellipsoid specific data.
 *
 * @author Ole Rahn
 * <br>
 * <br>FH Osnabr&uuml;ck - University of Applied Sciences Osnabr&uuml;ck,
 * <br>Project: PIROL (2006),
 * <br>Subproject: Daten- und Wissensmanagement
 * 
 * @version $Rev: 2519 $
 * 
 */
public abstract class AbstractEllipsoid {
    
    public final static int ELLIPSOID_ID_WGS = 0,
                             ELLIPSOID_ID_BESSEL = 1;
    
    public final static double radToDeg = 180.0/Math.PI;
    public final static double degToRad = Math.PI/180.0;
    
    /** c */
    protected double c = Double.NaN; 
    
    /** e */
    protected double e = Double.NaN; 
    
    /** e^2 */
    protected double eSquare = Double.NaN; 
    
    /** the other e */
    protected double e2 = Double.NaN; 
    
    /** the other e^2 */
    protected double eSquare2 = Double.NaN;

    /**
     * 
     *@return groe Hablbachse
     */
    abstract public double getA();

    /**
     * 
     *@return kleine Halbachse
     */
    abstract public double getB();
    
    /**
     *return <code>c=a^2/b</code>
     */
    public double getC() {
        if (Double.isNaN(c)){
            c = Math.pow(getA(),2)/getB();
        }
        return c;
    }
    
    /**
     * 
     *@return the ID of the specified ellipsoid
     */
    abstract public int getEllipsoidId();

    public double getESquare() {
        if (Double.isNaN(eSquare)){
            double a_square = getA() * getA();
            eSquare = (a_square-getB()*getB())/(a_square);
        }
        
        return eSquare;
    }

    public double getESquare2() {
        if (Double.isNaN(eSquare2)){
            double b_square = getB() * getB();
            eSquare2 = (getA()*getA()-b_square)/(b_square);
        }
        
        return eSquare2;
    }

    public double getE() {
        if (Double.isNaN(e)){
            e = Math.sqrt(getESquare());
        }
        
        return e;
    }
    
    public double getE2() {
        if (Double.isNaN(e2)){
            e2 = Math.sqrt(getESquare2());
        }
        
        return e2;
    }
    
}
